package com.ynet.life.controller;

import com.sun.image.codec.jpeg.JPEGCodec;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.session.Session;
import com.ynet.gene.web.servlet.ModelAndView;
import com.ynet.gene.web.servlet.mvc.GENEFlowExecuteResult;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.MVCEntity;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.mvc.MVCDataParseUtil;
import com.ynet.life.mvc.SimpleRequest;
import com.ynet.life.mvc.XMLViewRequestController;
import com.ynet.life.platform.util.PlatformUtil;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/* loaded from: com_ynet_life_controller.jar:com/ynet/life/controller/ImageDisplayController.class */
public class ImageDisplayController extends XMLViewRequestController {
    private String imageField = "image";
    private String recAccountNoField = "recAccount";
    private String recAccountNameField = "recAccountName";
    private String payAmountField = "payAmount";
    private String transferConfirmCodeField = "transferConfirmCode";

    public ModelAndView doRequest(HttpServletRequest request, HttpServletResponse response) throws Exception {
        Session session = doSessionCheck(request, response);
        if (session == null) {
            Trace.logError("LifeSession", "Session not exist or timeout");
            throw LifeConstants.EXCEPTION_SESSION_TIMEOUT;
        }
        GENEFlowExecuteResult result = executeGENELogicBizFlow(request, response, session);
        if (result.e != null) {
            throw result.e;
        }
        Context context = result.context;
        try {
            String recAccount = (String) context.get(this.recAccountNoField);
            String recAccountName = (String) context.get(this.recAccountNameField);
            String payAmount = (String) context.get(this.payAmountField);
            String trxCode = (String) context.get("trxCode");
            BufferedImage image = (BufferedImage) result.context.get(this.imageField);
            String transferConfirmCode = (String) result.context.get(this.transferConfirmCodeField);
            prepareTransferConfirmCodeSession(session, recAccount, recAccountName, payAmount, transferConfirmCode, trxCode);
            if (image == null) {
                Trace.logError(GENEConstance.GENE_MVC, "图片生成出错");
                context.terminate();
                return null;
            }
            OutputStream outputStream = null;
            try {
                try {
                    outputStream = response.getOutputStream();
                    response.setHeader("Pragma", "no-cache");
                    response.setHeader("Cache-Control", "no-cache");
                    response.setDateHeader("Expires", 0L);
                    response.setContentType("image/jpeg");
                    JPEGCodec.createJPEGEncoder(outputStream).encode(image);
                    outputStream.flush();
                    if (outputStream != null) {
                        try {
                            outputStream.close();
                        } catch (IOException unused) {
                        }
                    }
                } catch (IOException ex) {
                    Trace.logError(GENEConstance.GENE_MVC, "图片生成出错", ex);
                    if (outputStream != null) {
                        try {
                            outputStream.close();
                        } catch (IOException unused2) {
                        }
                    }
                }
                context.terminate();
                return null;
            } catch (Throwable th) {
                if (outputStream != null) {
                    try {
                        outputStream.close();
                    } catch (IOException unused3) {
                    }
                }
                throw th;
            }
        } catch (Throwable th2) {
            context.terminate();
            throw th2;
        }
    }

    protected void prepareTransferConfirmCodeSession(Session session, String recAccount, String recAccountName, String payAmount, String transferConfirmCode, String trxCode) {
        if (recAccount != null) {
            session.setAttribute(this.recAccountNoField, recAccount);
        }
        if (recAccountName != null) {
            session.setAttribute(this.recAccountNameField, recAccountName);
        }
        if (payAmount != null) {
            session.setAttribute(this.payAmountField, payAmount);
        }
        if (transferConfirmCode != null) {
            session.setAttribute(String.valueOf(this.transferConfirmCodeField) + "_" + trxCode, transferConfirmCode);
        }
    }

    public void setImageField(String imageField) {
        this.imageField = imageField;
    }

    protected void preContextWork(HttpServletRequest request, Context context, SimpleRequest simpleRequest) throws TranFailException {
        if (simpleRequest != null) {
            String appKey = request.getParameter(TEntity.appKeyFieldname);
            MVCEntity mvcEntity = (MVCEntity) ((Session) this.sessionManager.getSessions().get(appKey)).getAttribute(appKey);
            String bankId = mvcEntity.getBankId();
            mvcEntity.getChannel();
            String format = request.getParameter(TEntity.responseFormat);
            String uri = request.getRequestURI();
            String method = request.getMethod();
            if ("POST".equalsIgnoreCase(method)) {
                Map paramsMap = MVCDataParseUtil.getPostParamsMap(request);
                context.put("paramsMap", paramsMap);
            } else {
                String queryString = request.getQueryString();
                context.put(TEntity.queryStringFieldname, queryString);
            }
            LifeClientRequest.getClientIP(request);
            PlatformUtil.getBankId4LinkLAN(request);
            context.put(TEntity.sessionIdFieldName, appKey);
            context.put(TEntity.bankIdFieldName, bankId);
            context.put(TEntity.appKeyFieldname, appKey);
            context.put(TEntity.uriFieldname, uri);
            context.put(TEntity.channelFieldname, TEntity.JRBChannel);
            context.put(TEntity.responseFormat, format);
            context.put(TEntity.requestMethod, method);
            context.put(TEntity.IS_LOGIN, TEntity.isSign_NO);
            MVCDataParseUtil.setValueFromMVC(request, context);
        }
    }
}
